@@ -172,16 +172,15 @@ class BayesianOptimizer:
         """
         self.bestParametersByRegressor = dict()
         bestParameters = {"regressor": None, "score": float("inf"), "parameters": None}
-        loadedObjective = use_named_args(hyperparameterSpaces)(
-            partial(
-                objectiveToMinimize,
-                **{
-                    "model": model,
-                    "trainingData": trainingData,
-                    "trainingLabels": trainingLabels,
-                },
-            )
+        loadedObjective = partial(
+            objectiveToMinimize,
+            **{
+                "model": model,
+                "trainingData": trainingData,
+                "trainingLabels": trainingLabels,
+            },
         )
+
         optimizedResultList = []
         hyperparameterNames = [parameter.name for parameter in hyperparameterSpaces]
         for regressor in self.regressorCollection.selectedRegressors:
@@ -220,7 +219,7 @@ class BayesianOptimizer:
                     for points in sampledPoints
                 ]
                 optimizedParameters = Parallel(n_jobs=2)(
-                    delayed(loadedObjective)(**point) for point in sampledParameters
+                    delayed(loadedObjective)(point) for point in sampledParameters
                 )
                 # remove points that did not converge
                 if np.isnan(optimizedParameters).any():
